@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2022, Lawrence Livermore National Security
+ * Copyright (c) 2002-2023, Lawrence Livermore National Security
  * and Southern Methodist University.
  * All rights reserved.
  *
@@ -36,9 +36,9 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "6.3.0"
+#define SUNDIALS_VERSION "6.6.0"
 #define SUNDIALS_VERSION_MAJOR 6
-#define SUNDIALS_VERSION_MINOR 3
+#define SUNDIALS_VERSION_MINOR 6
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
@@ -101,7 +101,7 @@
 
 /* Is snprintf available? */
 #define SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
-#ifndef SUNDIALS_SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
+#ifndef SUNDIALS_C_COMPILER_HAS_SNPRINTF_AND_VA_COPY
 #define SUNDIALS_MAX_SPRINTF_SIZE 
 #endif
 
@@ -112,6 +112,13 @@
 /* Caliper */
 /* #undef SUNDIALS_CALIPER_ENABLED */
 
+/* Ginkgo backends */
+/* #undef SUNDIALS_GINKGO_BACKENDS_CUDA */
+/* #undef SUNDIALS_GINKGO_BACKENDS_HIP */
+/* #undef SUNDIALS_GINKGO_BACKENDS_OMP */
+/* #undef SUNDIALS_GINKGO_BACKENDS_REF */
+/* #undef SUNDIALS_GINKGO_BACKENDS_DPCPP */
+
 /* MAGMA backends */
 /* #undef SUNDIALS_MAGMA_BACKENDS_CUDA */
 /* #undef SUNDIALS_MAGMA_BACKENDS_HIP */
@@ -123,12 +130,16 @@
  */
 #define SUNDIALS_MPI_ENABLED 1
 
- /* SUPERLUMT threading type */
-/* #undef SUNDIALS_SUPERLUMT_THREAD_TYPE */
+/* oneMKL interface options */
+/* #undef SUNDIALS_ONEMKL_USE_GETRF_LOOP */
+/* #undef SUNDIALS_ONEMKL_USE_GETRS_LOOP */
 
- /* Trilinos with MPI is available, then
-  *    #define SUNDIALS_TRILINOS_HAVE_MPI
-  */
+/* SUPERLUMT threading type */
+#define SUNDIALS_SUPERLUMT_THREAD_TYPE ""
+
+/* Trilinos with MPI is available, then
+ *    #define SUNDIALS_TRILINOS_HAVE_MPI
+ */
 /* #undef SUNDIALS_TRILINOS_HAVE_MPI */
 
 /* RAJA backends */
@@ -136,6 +147,10 @@
 /* #undef SUNDIALS_RAJA_BACKENDS_HIP */
 /* #undef SUNDIALS_RAJA_BACKENDS_SYCL */
 
+/* SYCL options */
+/* #undef SUNDIALS_SYCL_2020_UNSUPPORTED */
+
+
 /* ------------------------------------------------------------------
  * SUNDIALS modules enabled
  * -----------------------------------------------------------------*/
